Module report

Module report 

The result of running the checks over a crawl.

Structs

CrawlReport
CrawlSummary
InlinkSample
An internal link to a page that has a problem, kept as a sample for the report.
StatusCounts