pub struct InlinkSample {
pub target: u32,
pub source: u32,
pub anchor: String,
pub nofollow: bool,
}Expand description
An internal link to a page that has a problem, kept as a sample for the report.
Fields
target: u32Index of the page being linked to.
source: u32Index of the page holding the link.
anchor: Stringnofollow: boolTrait Implementations
Sourceimpl Clone for InlinkSample
impl Clone for InlinkSample
Sourceimpl Debug for InlinkSample
impl Debug for InlinkSample
Sourceimpl<'de> Deserialize<'de> for InlinkSample
impl<'de> Deserialize<'de> for InlinkSample
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for InlinkSample
Sourceimpl PartialEq for InlinkSample
impl PartialEq for InlinkSample
Sourceimpl Serialize for InlinkSample
impl Serialize for InlinkSample
impl StructuralPartialEq for InlinkSample